pysmug.smugmug.HTTPException

Package pysmug :: Module smugmug :: Class HTTPException |
[hide private]
[frames] | no frames]

# Class HTTPException

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                    SmugMugException --+
                                       |
                                      HTTPException

An exception thrown during http(s) communication.

Instance Methods | [hide private]
Inherited from `SmugMugException`: `__init__`, `__repr__`, `__str__` Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__setattr__`, `__setstate__` Inherited from `object`: `__hash__`, `__reduce_ex__`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args`, `message` Inherited from `object`: `__class__`